@@ -16,10 +16,24 @@
 # General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this package; see the file COPYING.  If not, write to
-# the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-# Boston, MA 02110-1301, USA.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 #
 # Just call autoreconf -i.  This script should really go away, but we're
 # keeping it, because people are used to it.
-exec autoreconf -i
+rm -f ABOUT-NLS
+rm -f po/remove-potcdate.sin
+autoreconf -i
+
+# See https://savannah.gnu.org/bugs/index.php?54809
+rm -f \
+./po/remove-potcdate.sin \
+./po/quot.sed \
+./po/boldquot.sed \
+./po/en@quot.header \
+./po/en@boldquot.header \
+./po/insert-header.sin \
+./po/Rules-quot \
+./ABOUT-NLS
+
+touch ABOUT-NLS
+touch po/remove-potcdate.sin
