@@ -7,18 +7,17 @@
 ;; COPYRIGHT NOTICE
 
 ;; This program is free software; you can redistribute it and/or modify
-;; it under the terms of the GNU General Public License as published by
-;; the Free Software Foundation; either version 2 of the License, or
+;; it under the terms of the GNU Lesser General Public License as published by
+;; the Free Software Foundation; either version 2.1 of the License, or
 ;; (at your option) any later version.
 
 ;; This program is distributed in the hope that it will be useful, but
 ;; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
 ;; for more details.
 
-;; You should have received a copy of the GNU General Public License
-;; along with this program; if not, write to the Free Software
-;; Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+;; You should have received a copy of the GNU Lesser General Public License
+;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 
 ;;; Note: This library was ported from the Elisp library, so don't wonder much
@@ -79,6 +78,7 @@ Useful only for diagnosing problems.")
     (voice . "VOICE")
     (rate . "RATE")
     (pitch . "PITCH")
+    (pitch_range . "PITCH_RANGE")
     (spelling-mode . "SPELLING")
     (output-module . "OUTPUT_MODULE")
     ))
@@ -383,7 +383,7 @@ Return the opened connection on success, nil otherwise."
     ("key")
     ("quit")
     ("block" ("end"))
-    ("set" ("self" ("rate" "pitch" "voice" "language")))))
+    ("set" ("self" ("rate" "pitch" "pitch_range" "voice" "language")))))
 
 (defun block-command-p (command &optional allowed)
   (unless allowed
