@@ -14,9 +14,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * @author: Olivier BERT
  */
@@ -42,6 +40,8 @@
 // #define DEBUG_MODULE 1
 DECLARE_DEBUG()
 
+static int initialized = 0;
+
 /* Thread and process control */
 static int cicero_speaking = 0;
 
@@ -147,6 +147,11 @@ int module_init(char **status_info)
 
 	DBG("Module init\n");
 
+	if (access(CiceroExecutable, X_OK) != 0) {
+		DBG("ERROR: can not reach executable %s", CiceroExecutable);
+		return -1;
+	}
+
 	(void)signal(SIGPIPE, SIG_IGN);
 
 	DBG("call the pipe system call\n");
@@ -191,6 +196,8 @@ int module_init(char **status_info)
 			exit(1);
 		}
 	default:{
+			if (stderr_redirect >= 0)
+				close(stderr_redirect);
 			close(fd1[1]);
 			close(fd2[0]);
 			if (fcntl(fd2[1], F_SETFL, O_NDELAY) < 0
@@ -222,6 +229,8 @@ int module_init(char **status_info)
 
 	*status_info = g_strdup("Cicero initialized successfully.");
 
+	initialized = 1;
+
 	return 0;
 }
 
@@ -292,10 +301,15 @@ int module_close(void)
 		module_stop();
 	}
 
+	if (!initialized)
+		return 0;
+
 	if (module_terminate_thread(cicero_speaking_thread) != 0)
 		return -1;
 
 	sem_destroy(&cicero_semaphore);
+
+	initialized = 0;
 	return 0;
 }
 
