@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * $Id: config.h,v 1.4 2007-02-17 18:58:27 hanke Exp $
  */
@@ -37,7 +35,7 @@ int spd_num_options;
 configoption_t *load_config_options(int *num_options);
 void free_config_options(configoption_t * opts, int *num);
 configoption_t *add_config_option(configoption_t * options,
-				  int *num_config_options, char *name, int type,
+				  int *num_config_options, const char *name, int type,
 				  dotconf_callback_t callback, info_t * info,
 				  unsigned long context);
 
