@@ -15,9 +15,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this package; see the file COPYING.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
  * $Id: speaking.c,v 1.56 2008-10-15 18:06:48 hanke Exp $
  */
@@ -33,6 +31,7 @@
 #include "speechd.h"
 #include "server.h"
 #include "index_marking.h"
+#include "symbols.h"
 #include "module.h"
 #include "set.h"
 #include "alloc.h"
@@ -220,6 +219,8 @@ void *speak(void *data)
 
 		/* Insert index marks into textual messages */
 		if (message->settings.type == SPD_MSGTYPE_TEXT) {
+			if (message->settings.symbols_preprocessing)
+				insert_symbols(message);
 			insert_index_marks(message,
 					   message->settings.ssml_mode);
 		}
